<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="sl" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategorija:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Začni torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Preskoči preverjanje šifre</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Ustvari podmapo</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Ne kategorizirani</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Dodaj kategorijo...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Odstrani kategorijo</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Odstrani neuporabljene kategorije</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Nadaljuj torrente</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Ustavi torrente</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Izbriši torrente</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit category...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Zapri qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Samo ena povezava na vrstico</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Splošna omejitev razmerja pošiljanja mora biti večja od 0 ali onemogočena.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Splošna omejitev razmerja prejema mora biti večja od 0 ali onemogočena.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Nadomestna omejitev razmerja pošiljanja mora biti večja od 0 ali onemogočena.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Nadomestna omejitev razmerja prejema mora biti večja od 0 ali onemogočena.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Največje število dejavnih prejemov mora biti večje od -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Največje število dejavnih pošiljanj mora biti večje od -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Največje število dejavnih torrentov mora biti večje od -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Največje število povezav mora biti večje od 0 ali onemogočeno.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Največje število povezav na torrent mora biti večje od 0 ali onemogočeno.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Največje število povezav za pošiljanje na torrent mora biti večje od 0 ali onemogočeno.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Ni mogoče shraniti možnosti programa, qBittorrent je verjetno nedosegljiv.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent na Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nezano</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Omejitev razmerja izmenjave mora biti med 0 in 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Omejitev časa sejanja mora biti med 0 525600 minut.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Vrata uporabljena za dohodne povezave morajo biti med 1 in 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Vrata uporabljena za spletni vmesnik morajo biti med 1 in 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Prijava ni mogoča, qBittorrent je verjetno nedosegljiv.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Neveljavno uporabniško ime ali geslo.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prijava</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Izvirni avtorji</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Uveljavi</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Pošlji torrente</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Shrani datoteke v:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Piškotek:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Vnesite mesto mape</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Več podrobnosti</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Podrobnosti o potrdilih</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nastavi lokacijo</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Omejitev razmerja pošiljanja</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Omejitev razmerja prejemanja</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Preimenuj torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Drugo...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Ponedeljek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Torek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sreda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Četrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Petek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Nedelja</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Prejmi torrente preko URL ali magnetne povezave.</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Pošlji krajevni torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Ali ste prepričani, da želite izbrisati izbrane torrente iz seznama prenosov?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Odjemalec qBittorrent ni dosegljiv</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Free space: %1</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Orodja</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Možnosti ...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Najmanjša prednost</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Najvišja prednost</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Zmanjšaj prednost</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Povišaj prednost</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Zgornja orodna vrstica</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Vrstica stanja</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Hitrost v naslovni vrstici</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Podari!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Nadaljuj vse</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Premor vseh</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Dodaj datoteko torrent ...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentacija</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Dodaj torrent povezavo</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Splošna omejitev hitrosti pošiljanja</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Splošna omejitev hitrosti prejemanja</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Ali ste prepričani, da želite zapreti qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[Pr: %1, Po: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Prejemi</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Povezava</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Spletni vmesnik</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jezik</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Jezik uporabniškega vmesnika:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Pošlji e-poštno obvestilo ob zaključku prejema</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Ko se torrent zaključi zaženi zunanji program</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtriranje IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Načrtujte uporabo nadomestnih omejitev hitrosti</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Čakalna vrsta torrentov</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Seji torrente, dokler čas sejanja ne doseže</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Samodejno dodaj te sledilnike novim prenosom:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Spletni uporabniški vmesnik (Oddaljen nadzor)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP naslov:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domene strežnika:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Uporabi HTTPS namesto HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Obidi overitev za odjemalce na lokalnem gostitelju</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Obidi overitev za odjemalce na seznamu dovoljenih IP podmrež</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Posodobi moje dinamično ime domene</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Hrani nedokončane torrente v:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopiraj datoteke .torrent v:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Za zaključene prejeme kopiraj datoteke .torrent v:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Predhodno dodeli prostor na disku za vse datoteke</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Dodaj pripono .!qB nedokončanim datotekam</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Samodejno dodaj torrente iz:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Strežnik SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Ta strežnik  zahteva varno povezavo (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Overitev</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Geslo:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Omogočen protokol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP in μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Vrata za poslušanje</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Uporabljena vrata za dohodne povezave:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Uporabi UPnP / NAT-PMP posredovanje vrat od mojega usmerjevalnika</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Uporabi druga vrata ob vsakem zagonu</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Omejitve povezav</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Najvišje število povezav na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Najvišje splošno število povezav:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Najvišje število povezav za pošiljanje na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Najvišje splošno število povezav za pošiljanje na torrent:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Posredniški strežnik</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Brez)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Gostitelj:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Vrata:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Uporabi posredniški strežnik za povezave s soležniki</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Onemogoči povezave, ki jih posredniški strežniki ne podpirajo</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Uporabi posredniški strežnik le za torrente</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Pot filtra (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Ročno izločeni IP naslovi...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Uveljavi pri sledilcih</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Splošne omejitve hitrosti</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Pošiljanje:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Prejem:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Nadomestne omejitve hitrosti</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Od:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Do:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kdaj:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Vsak dan</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Med tednom</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Vikendi</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Nastavitve omejitev hitrosti</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Uveljavi omejitev razmerja v slepi prenos</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Uveljavi omejitve hitrosti za µTP protokol</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Zasebnost</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Omogočite DHT (decentralizirano omrežje) da najdete več soležnikov</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Omogočite Izmenjavo soležnikov (PeX) da najdete več soležnikov</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Omogočite odkrivanje krajevnih soležnikov za iskanje več soležnikov</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Način šifriranja:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Prednost šifriranju</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Zahtevaj šifriranje</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Onemogoči šifriranje</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Omogoči anonimni način</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Največ dejavnih prejemov:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Največ dejavnih pošiljanj:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Največ dejavnih torrentov:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>V teh omejitvah ne štej počasnih torrentov</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Omejevanje  razmerja izmenjave</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Seji torrente, dokler razmerje ne doseže</translation>
    </message>
    <message>
        <source>then</source>
        <translation>nato</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Jih ustavi</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Jih odstrani</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Uporabi UPnP / NAT-PMP za posredovanje vrat od mojega usmerjevalnika</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Potrdilo:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Ključ:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Vpis</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Ime domene:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Podprti parametri (razlikovanje velikosti črk):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Ime torrenta</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategorija</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Pot vsebine (enaka kot korenska pot za večdatotečni torrent)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Korenska pot (pot podmape prvega torrenta)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Mesto za shranjevanje</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Število datotek</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Velikost torrenta (bajti)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Trenutni sledilnik</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info šifra</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Namig: Postavi parameter med narekovaje da se izogneš prelomu teksta na presledku (npr., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Uporabniško ime za spletni vmesnik mora vsebovati vsaj 3 znake.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Geslo za spletni vmesnik mora vsebovati vsaj 6 znakov.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Vrata</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Zastavice</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Povezava</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Odjemalec</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Napredek</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Hitrost prejema</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Hitrost pošiljanja</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Prejeto</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Pomembnost</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Datoteke</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Država</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normalna</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Visoka</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Najvišja</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Sledilniki</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Soležniki</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Viri HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Vsebina</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Prejeto:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Prenos</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Čas delovanja:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Preostal čas:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Poslano:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Semena:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Hitrost prejema:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Hitrost pošiljanja:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Soležniki:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Omejitev prejema:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Omejitev pošiljanja:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Zavrženo:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Povezave:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Deli razmerje:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Ponovno objavi čez:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Nazadnje videno v celoti:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Skupna velikost:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Kosov:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Ustvarjeno od:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Dodano:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Zaključeno:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Ustvarjeno:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Šifra torrenta:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Mesto:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ima %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1(%2 to sejo)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1(%2 max)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1(%2 skupno)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1(%2 povpr.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Nadzorovana mapa</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Prepiši mesto shranjevanja</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Nadzorovana mapa</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Privzeto mesto za shranjevanje</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistika uporabnika</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistika predpomnilnika</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Zadetki branja predpomnilnika:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Povprečen čas v čakalni vrsti:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistika zmogljivosti</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Posli I/O v čakalni vrsti:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Preobremenitev pisanja predpomnilnika:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Preobremenitev branja predpomnilnika:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Skupna velikost v čakalni vrsti:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 vozlišč</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Vsi (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Prejemanje (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Sejanje (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Končano (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Se nadaljuje (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>V premoru (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Dejavno (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Nedejavno (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Napaka (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Vsi (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Prejemanje (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Sejanje (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Končano (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>V premoru (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Se nadaljuje (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Dejavno (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Nedejavno (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Napaka (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Napredek</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioriteta prenosov</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Preostalo</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Na voljo</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Končano</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Stanje</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Semena</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Soležniki</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Hitrost prejema</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Hitrost pošiljanja</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Razmerje</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Preostali čas</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Oznake</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Dodano</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Končano</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Sledilnik</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Omejitev prejemanja</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Omejitev pošiljanja</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Prejeto</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Prejeto v seji</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Poslano v seji</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Preostalo</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Čas delovanja</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Mesto</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Končano</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Omejitev razmerja</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Nazadnje videno v celoti</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Zadnja dejavnost</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Skupna velikost</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stanje</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Soležniki</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Sporočilo</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Pogovorno okno za dodajanje sledilnikov</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Seznam sledilnikov za dodajanje (en na vrstico):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 nazaj</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Stanje</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorije</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Omejitev hitrosti prejemanja torrenta</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Omejitev hitrosti pošiljanja torrenta</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Prisili nadaljevanje</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Omeji razmerje izmenjave ...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Omejitev razmerja pošiljanja ...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Omejitev razmerja prejemanja ...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Premakni navzgor</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Premakni navzdol</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Premakni na vrh</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Premakni na dno</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Nastavi mesto ...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopiraj ime</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopiraj šifro</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Prejemanje najprej prvih in zadnjih kosov</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Samodejno Upravljanje Torrenta</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nova...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Ponastavi</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioriteta</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Prisili ponovno preverjanje</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopiraj magnetno povezavo</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Način super sejanja</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Preimenuj...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Prejemanje v zaporednem vrstnem redu</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Omejevanje torrent razmerja pošiljanja/prejemanja</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Uporabi splošno omejitev izmanjave</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Ne nastavi omejitve izmenjave</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Nastavi omejitev deljenja na</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>razmerje</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Napreden odjemalec BitTorrent, programiran v C++, temelji na zbirki orodij Qt in libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domača stran:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum: </translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Sledilnik hroščev:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Potrditev odstranjevanja</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Odstrani tudi datoteke na trdem disku</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Prejemi z URLjev</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Prenesi</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Go to description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>